(function(){var a={}.hasOwnProperty,b=function(f,d){for(var c in d){if(a.call(d,c)){f[c]=d[c]}}function e(){this.constructor=f}e.prototype=d.prototype;f.prototype=new e();f.__super__=d.prototype;return f};window.Controls.bind__template=(function(d){b(c,d);function c(){return c.__super__.constructor.apply(this,arguments)}c.prototype.createDom=function(){this.noUID=true;return"<children>"};c.prototype.setupDom=function(e){c.__super__.setupDom.call(this,e);if(this.children.length>0){this.dom=this.children[0].dom;return this.properties=this.children[0].properties}};return c})(window.Control)}).call(this);