(function(){var a;a=(function(){function b(){this.profiles={};this.results={};this.timeout=null;this.stack=[]}b.prototype.start=function(d){var c;if(this.profiles[d]){return this.stack.push(null)}else{if((c=this.profiles)[d]==null){c[d]=new Date().getTime()}return this.stack.push(d)}};b.prototype.stop=function(d){var c;if(d==null){d=this.stack.pop()}if(d===null){return}if((c=this.results)[d]==null){c[d]=0}this.results[d]+=new Date().getTime()-this.profiles[d];this.profiles[d]=void 0;clearTimeout(this.timeout);return this.timeout=setTimeout((function(e){return function(){return e.dump()}})(this),1000)};b.prototype.dump=function(){var c;for(c in this.results){console.log("Profiled",c,this.results[c]/1000,"s")}return this.results={}};return b})();window.profiler=new a()}).call(this);